@@ -1,3 +1,3 @@
-HOST = "107.20.226.184:8000"
-HTTPS_PROTOCOL = "http://"
+HOST = "prod.skylarklabs.ai"
+HTTPS_PROTOCOL = "https://"
 WEBSOCKET_AUTH_API = "%s%s/%s" % (HTTPS_PROTOCOL, HOST, "console/web-socket-token/")
